@@ -26,6 +26,7 @@ import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codecommit._jsii
 import aws_cdk.aws_codeguruprofiler._jsii
 import aws_cdk.aws_codepipeline._jsii
+import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_databrew._jsii
 import aws_cdk.aws_docdb._jsii
@@ -41,6 +42,7 @@ import aws_cdk.aws_elasticloadbalancing._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
+import aws_cdk.aws_fsx._jsii
 import aws_cdk.aws_globalaccelerator._jsii
 import aws_cdk.aws_glue._jsii
 import aws_cdk.aws_iam._jsii
@@ -48,6 +50,7 @@ import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_kinesisfirehose._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_lambda_nodejs._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_targets._jsii
@@ -69,11 +72,12 @@ import aws_cdk.custom_resources._jsii
 import aws_cdk.cx_api._jsii
 import aws_cdk.lambda_layer_awscli._jsii
 import aws_cdk.lambda_layer_kubectl._jsii
+import aws_cdk.lambda_layer_node_proxy_agent._jsii
 import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "aws-rfdk", "0.34.0", __name__[0:-6], "aws-rfdk@0.34.0.jsii.tgz"
+    "aws-rfdk", "0.38.0", __name__[0:-6], "aws-rfdk@0.38.0.jsii.tgz"
 )
 
 __all__ = [
